@@ -43,7 +43,7 @@ def _open_file(filename):
         return open(
             _unicode_encode(filename, encoding=_encodings["fs"], errors="strict"), "rb"
         )
-    except IOError as e:
+    except OSError as e:
         func_call = f"open('{_unicode_decode(filename)}')"
         if e.errno == errno.EPERM:
             raise portage.exception.OperationNotPermitted(func_call)
@@ -310,10 +310,13 @@ if "STREEBOG256" not in hashfunc_map or "STREEBOG512" not in hashfunc_map:
 _whirlpool_unaccelerated = False
 if "WHIRLPOOL" not in hashfunc_map:
     # Bundled WHIRLPOOL implementation
-    _whirlpool_unaccelerated = True
-    from portage.util.whirlpool import new as _new_whirlpool
+    from portage.util.whirlpool import CWhirlpool, PyWhirlpool
 
-    _generate_hash_function("WHIRLPOOL", _new_whirlpool, origin="bundled")
+    if CWhirlpool.is_available:
+        _generate_hash_function("WHIRLPOOL", CWhirlpool, origin="bundled-c")
+    else:
+        _whirlpool_unaccelerated = True
+        _generate_hash_function("WHIRLPOOL", PyWhirlpool, origin="bundled-py")
 
 
 # There is only one implementation for size
@@ -339,7 +342,7 @@ if os.path.exists(PRELINK_BINARY):
     proc.communicate()
     status = proc.wait()
     if os.WIFEXITED(status) and os.WEXITSTATUS(status) == os.EX_OK:
-        prelink_capable = 1
+        prelink_capable = True
     del cmd, proc, status
 
 
@@ -574,7 +577,7 @@ def perform_checksum(filename, hashname="MD5", calc_prelink=0):
                     f"{hashname} hash function not available (needs dev-python/pycrypto)"
                 )
             myhash, mysize = hashfunc_map[hashname].checksum_file(myfilename)
-        except (OSError, IOError) as e:
+        except OSError as e:
             if e.errno in (errno.ENOENT, errno.ESTALE):
                 raise portage.exception.FileNotFound(myfilename)
             elif e.errno == portage.exception.PermissionDenied.errno:
