@@ -104,33 +104,31 @@ class bindbapi(fakedbapi):
         self.bintree = mybintree
         self.move_ent = mybintree.move_ent
         # Selectively cache metadata in order to optimize dep matching.
-        self._aux_cache_keys = set(
-            [
-                "BDEPEND",
-                "BUILD_ID",
-                "BUILD_TIME",
-                "CHOST",
-                "DEFINED_PHASES",
-                "DEPEND",
-                "EAPI",
-                "IDEPEND",
-                "IUSE",
-                "KEYWORDS",
-                "LICENSE",
-                "MD5",
-                "PDEPEND",
-                "PROPERTIES",
-                "PROVIDES",
-                "RDEPEND",
-                "repository",
-                "REQUIRES",
-                "RESTRICT",
-                "SIZE",
-                "SLOT",
-                "USE",
-                "_mtime_",
-            ]
-        )
+        self._aux_cache_keys = {
+            "BDEPEND",
+            "BUILD_ID",
+            "BUILD_TIME",
+            "CHOST",
+            "DEFINED_PHASES",
+            "DEPEND",
+            "EAPI",
+            "IDEPEND",
+            "IUSE",
+            "KEYWORDS",
+            "LICENSE",
+            "MD5",
+            "PDEPEND",
+            "PROPERTIES",
+            "PROVIDES",
+            "RDEPEND",
+            "repository",
+            "REQUIRES",
+            "RESTRICT",
+            "SIZE",
+            "SLOT",
+            "USE",
+            "_mtime_",
+        }
         self._aux_cache_slot_dict = slot_dict_class(self._aux_cache_keys)
         self._aux_cache = {}
 
@@ -244,7 +242,6 @@ class bindbapi(fakedbapi):
     def aux_update(self, cpv, values):
         if not self.bintree.populated:
             self.bintree.populate()
-        build_id = None
         try:
             build_id = cpv.build_id
         except AttributeError:
@@ -257,6 +254,10 @@ class bindbapi(fakedbapi):
                 cpv = self._instance_key(cpv, support_string=True)[0]
                 build_id = cpv.build_id
 
+        cpv_str = str(cpv)
+        if build_id is not None:
+            cpv_str += f"-{build_id}"
+
         binpkg_path = self.bintree.getname(cpv)
         if not os.path.exists(binpkg_path):
             raise KeyError(cpv)
@@ -267,7 +268,7 @@ class bindbapi(fakedbapi):
             mydata = mytbz2.get_data()
             encoding_key = True
         elif binpkg_format == "gpkg":
-            mybinpkg = portage.gpkg.gpkg(self.settings, cpv, binpkg_path)
+            mybinpkg = portage.gpkg.gpkg(self.settings, cpv_str, binpkg_path)
             mydata = mybinpkg.get_metadata()
             encoding_key = False
         else:
@@ -522,7 +523,6 @@ class binarytree:
             "SLOT",
             "USE",
         ]
-        self._pkgindex_aux_keys = list(self._pkgindex_aux_keys)
         self._pkgindex_use_evaluated_keys = (
             "BDEPEND",
             "DEPEND",
@@ -534,26 +534,24 @@ class binarytree:
             "RESTRICT",
         )
         self._pkgindex_header = None
-        self._pkgindex_header_keys = set(
-            [
-                "ACCEPT_KEYWORDS",
-                "ACCEPT_LICENSE",
-                "ACCEPT_PROPERTIES",
-                "ACCEPT_RESTRICT",
-                "CBUILD",
-                "CONFIG_PROTECT",
-                "CONFIG_PROTECT_MASK",
-                "FEATURES",
-                "GENTOO_MIRRORS",
-                "INSTALL_MASK",
-                "IUSE_IMPLICIT",
-                "USE",
-                "USE_EXPAND",
-                "USE_EXPAND_HIDDEN",
-                "USE_EXPAND_IMPLICIT",
-                "USE_EXPAND_UNPREFIXED",
-            ]
-        )
+        self._pkgindex_header_keys = {
+            "ACCEPT_KEYWORDS",
+            "ACCEPT_LICENSE",
+            "ACCEPT_PROPERTIES",
+            "ACCEPT_RESTRICT",
+            "CBUILD",
+            "CONFIG_PROTECT",
+            "CONFIG_PROTECT_MASK",
+            "FEATURES",
+            "GENTOO_MIRRORS",
+            "INSTALL_MASK",
+            "IUSE_IMPLICIT",
+            "USE",
+            "USE_EXPAND",
+            "USE_EXPAND_HIDDEN",
+            "USE_EXPAND_IMPLICIT",
+            "USE_EXPAND_UNPREFIXED",
+        }
         self._pkgindex_default_pkg_data = {
             "BDEPEND": "",
             "BUILD_ID": "",
@@ -1094,7 +1092,7 @@ class binarytree:
                         build_id = self._parse_build_id(myfile)
                         if build_id < 1:
                             invalid_name = True
-                        elif myfile != "%s-%s.xpak" % (mypf, build_id):
+                        elif myfile != "{}-{}.xpak".format(mypf, build_id):
                             invalid_name = True
                         else:
                             mypkg = mypkg[: -len(str(build_id)) - 1]
@@ -1102,7 +1100,7 @@ class binarytree:
                         build_id = self._parse_build_id(myfile)
                         if build_id > 0:
                             multi_instance = True
-                            if myfile != "%s-%s.gpkg.tar" % (mypf, build_id):
+                            if myfile != "{}-{}.gpkg.tar".format(mypf, build_id):
                                 invalid_name = True
                             else:
                                 mypkg = mypkg[: -len(str(build_id)) - 1]
@@ -1133,7 +1131,7 @@ class binarytree:
                         build_id = None
 
                     if multi_instance:
-                        name_split = catpkgsplit("%s/%s" % (mycat, mypf))
+                        name_split = catpkgsplit("{}/{}".format(mycat, mypf))
                         if (
                             name_split is None
                             or tuple(catsplit(mydir)) != name_split[:2]
@@ -1253,7 +1251,7 @@ class binarytree:
                     user, passwd = user.split(":", 1)
 
             if port is not None:
-                port_str = ":%s" % (port,)
+                port_str = ":{}".format(port)
                 if host.endswith(port_str):
                     host = host[: -len(port_str)]
             pkgindex_file = os.path.join(
@@ -1266,11 +1264,10 @@ class binarytree:
             )
             pkgindex = self._new_pkgindex()
             try:
-                f = io.open(
+                f = open(
                     _unicode_encode(
                         pkgindex_file, encoding=_encodings["fs"], errors="strict"
                     ),
-                    mode="r",
                     encoding=_encodings["repo.content"],
                     errors="replace",
                 )
@@ -1278,7 +1275,7 @@ class binarytree:
                     pkgindex.read(f)
                 finally:
                     f.close()
-            except EnvironmentError as e:
+            except OSError as e:
                 if e.errno != errno.ENOENT:
                     raise
             local_timestamp = pkgindex.header.get("TIMESTAMP", None)
@@ -1330,7 +1327,7 @@ class binarytree:
                         )
                         if hasattr(f, "headers") and f.headers.get("timestamp", ""):
                             remote_timestamp = f.headers.get("timestamp")
-                    except IOError as err:
+                    except OSError as err:
                         if (
                             hasattr(err, "code") and err.code == 304
                         ):  # not modified (since local_timestamp)
@@ -1359,7 +1356,7 @@ class binarytree:
                         # matches that of the cached Packages file.
                         ssh_args = ["ssh"]
                         if port is not None:
-                            ssh_args.append("-p%s" % (port,))
+                            ssh_args.append("-p{}".format(port))
                         # NOTE: shlex evaluates embedded quotes
                         ssh_args.extend(
                             portage.util.shlex_split(
@@ -1380,7 +1377,7 @@ class binarytree:
                             if not fcmd:
                                 fcmd = self.settings.get("FETCHCOMMAND")
                                 if not fcmd:
-                                    raise EnvironmentError("FETCHCOMMAND is unset")
+                                    raise OSError("FETCHCOMMAND is unset")
                         else:
                             fcmd = repo.fetchcommand
 
@@ -1403,7 +1400,7 @@ class binarytree:
                             fcmd=fcmd, fcmd_vars=fcmd_vars
                         )
                         if not success:
-                            raise EnvironmentError("%s failed" % (setting,))
+                            raise OSError("{} failed".format(setting))
                         f = open(tmp_filename, "rb")
 
                 f_dec = codecs.iterdecode(
@@ -1464,7 +1461,7 @@ class binarytree:
                     + "\n"
                 )
                 rmt_idx = pkgindex
-            except EnvironmentError as e:
+            except OSError as e:
                 # This includes URLError which is raised for SSL
                 # certificate errors when PEP 476 is supported.
                 writemsg(
@@ -1499,7 +1496,7 @@ class binarytree:
                     f = atomic_ofstream(pkgindex_file)
                     pkgindex.write(f)
                     f.close()
-                except (IOError, PortageException):
+                except (OSError, PortageException):
                     if os.access(os.path.dirname(pkgindex_file), os.W_OK):
                         raise
                     # The current user doesn't have permission to cache the
@@ -1980,7 +1977,7 @@ class binarytree:
                 deps = use_reduce(deps, uselist=use, token_class=token_class)
                 deps = paren_enclose(deps)
             except portage.exception.InvalidDependString as e:
-                writemsg("%s: %s\n" % (k, e), noiselevel=-1)
+                writemsg("{}: {}\n".format(k, e), noiselevel=-1)
                 raise
             metadata[k] = deps
 
@@ -2031,7 +2028,7 @@ class binarytree:
         filename = None
         build_id = None
         if allocate_new:
-            filename, build_id = self._allocate_filename(cpv)
+            filename, build_id = self._allocate_filename(cpv, remote_binpkg_format)
         elif self._is_specific_instance(cpv):
             instance_key = self.dbapi._instance_key(cpv)
             path = self._pkg_paths.get(instance_key)
@@ -2062,7 +2059,7 @@ class binarytree:
             elif binpkg_format == "xpak":
                 if self._multi_instance:
                     pf = catsplit(cpv)[1]
-                    filename = "%s-%s.xpak" % (
+                    filename = "{}-{}.xpak".format(
                         os.path.join(self.pkgdir, cpv.cp, pf),
                         "1",
                     )
@@ -2071,7 +2068,7 @@ class binarytree:
             elif binpkg_format == "gpkg":
                 if self._multi_instance:
                     pf = catsplit(cpv)[1]
-                    filename = "%s-%s.gpkg.tar" % (
+                    filename = "{}-{}.gpkg.tar".format(
                         os.path.join(self.pkgdir, cpv.cp, pf),
                         "1",
                     )
@@ -2254,15 +2251,14 @@ class binarytree:
     def _load_pkgindex(self):
         pkgindex = self._new_pkgindex()
         try:
-            f = io.open(
+            f = open(
                 _unicode_encode(
                     self._pkgindex_file, encoding=_encodings["fs"], errors="strict"
                 ),
-                mode="r",
                 encoding=_encodings["repo.content"],
                 errors="replace",
             )
-        except EnvironmentError:
+        except OSError:
             pass
         else:
             try:
