@@ -16,7 +16,6 @@ __all__ = [
 from collections import OrderedDict
 
 import fnmatch
-import io
 import logging
 import os as _os
 import re
@@ -80,7 +79,7 @@ class NewsManager:
         portdir = portdb.repositories.mainRepoLocation()
         profiles_base = None
         if portdir is not None:
-            profiles_base = os.path.join(portdir, "profiles", os.path.sep)
+            profiles_base = os.path.join(portdir, ("profiles" + os.path.sep))
         profile_path = None
         if profiles_base is not None and portdb.settings.profile_path:
             profile_path = normalize_path(
@@ -280,11 +279,16 @@ class NewsItem:
 
         kwargs = {"vardb": vardb, "config": config, "profile": profile}
 
-        all_match = all(
-            restriction.checkRestriction(**kwargs)
-            for values in self.restrictions.values()
-            for restriction in values
-        )
+        all_match = True
+        for values in self.restrictions.values():
+            matches = [restriction.checkRestriction(**kwargs) for restriction in values]
+            any_match = any(matches)
+
+            # If, for a single restriction, we didn't match anything, then we obviously
+            # didn't match everything, so just bail out.
+            if not any_match:
+                all_match = False
+                break
 
         return all_match
 
@@ -294,9 +298,8 @@ class NewsItem:
         return self._valid
 
     def parse(self):
-        with io.open(
+        with open(
             _unicode_encode(self.path, encoding=_encodings["fs"], errors="strict"),
-            mode="r",
             encoding=_encodings["content"],
             errors="replace",
         ) as f:
@@ -474,20 +477,23 @@ def count_unread_news(portdb, vardb, repos=None, update=True):
     return news_counts
 
 
-def display_news_notifications(news_counts):
+def display_news_notifications(news_counts: dict):
     """
     Display a notification for unread news items, using a dictionary mapping
     repos to integer counts, like that returned from count_unread_news().
+
+    @param news_count: mapping of repos to integer counts of unread news items
+    @type news_count: dict
     """
-    newsReaderDisplay = False
+    news_reader_display = False
     for repo, count in news_counts.items():
         if count > 0:
-            if not newsReaderDisplay:
-                newsReaderDisplay = True
+            if not news_reader_display:
+                news_reader_display = True
                 print()
             print(colorize("WARN", " * IMPORTANT:"), end=" ")
             print(f"{count} news items need reading for repository '{repo}'.")
 
-    if newsReaderDisplay:
+    if news_reader_display:
         print(colorize("WARN", " *"), end=" ")
         print(f"Use {colorize('GOOD', 'eselect news read')} to view new items.\n")
