@@ -20,12 +20,12 @@ def display_preserved_libs(vardb, verbose=False):
         linkmap.rebuild()
     except portage.exception.CommandNotFound as e:
         portage.util.writemsg_level(
-            "!!! Command Not Found: %s\n" % (e,), level=logging.ERROR, noiselevel=-1
+            "!!! Command Not Found: {}\n".format(e), level=logging.ERROR, noiselevel=-1
         )
     else:
         search_for_owners = set()
         for cpv in plibdata:
-            internal_plib_keys = set(linkmap._obj_key(f) for f in plibdata[cpv])
+            internal_plib_keys = {linkmap._obj_key(f) for f in plibdata[cpv]}
             for f in plibdata[cpv]:
                 if f in consumer_map:
                     continue
@@ -67,7 +67,7 @@ def display_preserved_libs(vardb, verbose=False):
         for alt_paths in samefile_map.values():
             alt_paths = sorted(alt_paths)
             for p in alt_paths:
-                print(colorize("WARN", " * ") + " - %s" % (p,))
+                print(colorize("WARN", " * ") + " - {}".format(p))
             f = alt_paths[0]
             consumers = consumer_map.get(f, [])
             consumers_non_preserved = [c for c in consumers if c not in all_preserved]
@@ -93,7 +93,8 @@ def display_preserved_libs(vardb, verbose=False):
                 else:
                     owners_desc = ", ".join(x.mycpv for x in owners.get(c, []))
                 print(
-                    colorize("WARN", " * ") + "     used by %s (%s)" % (c, owners_desc)
+                    colorize("WARN", " * ")
+                    + "     used by {} ({})".format(c, owners_desc)
                 )
             if not verbose and len(consumers) > max_display:
                 print(
