@@ -5,7 +5,6 @@ __all__ = ["env_update"]
 
 import errno
 import glob
-import io
 import stat
 import time
 
@@ -119,25 +118,23 @@ def _env_update(makelinks, target_root, prev_mtimes, contents, env, writemsg_lev
     fns = templist
     del templist
 
-    space_separated = set(["CONFIG_PROTECT", "CONFIG_PROTECT_MASK"])
-    colon_separated = set(
-        [
-            "ADA_INCLUDE_PATH",
-            "ADA_OBJECTS_PATH",
-            "CLASSPATH",
-            "INFODIR",
-            "INFOPATH",
-            "KDEDIRS",
-            "LDPATH",
-            "MANPATH",
-            "PATH",
-            "PKG_CONFIG_PATH",
-            "PRELINK_PATH",
-            "PRELINK_PATH_MASK",
-            "PYTHONPATH",
-            "ROOTPATH",
-        ]
-    )
+    space_separated = {"CONFIG_PROTECT", "CONFIG_PROTECT_MASK"}
+    colon_separated = {
+        "ADA_INCLUDE_PATH",
+        "ADA_OBJECTS_PATH",
+        "CLASSPATH",
+        "INFODIR",
+        "INFOPATH",
+        "KDEDIRS",
+        "LDPATH",
+        "MANPATH",
+        "PATH",
+        "PKG_CONFIG_PATH",
+        "PRELINK_PATH",
+        "PRELINK_PATH_MASK",
+        "PYTHONPATH",
+        "ROOTPATH",
+    }
 
     config_list = []
 
@@ -195,9 +192,8 @@ def _env_update(makelinks, target_root, prev_mtimes, contents, env, writemsg_lev
 
     ldsoconf_path = os.path.join(eroot, "etc", "ld.so.conf")
     try:
-        myld = io.open(
+        myld = open(
             _unicode_encode(ldsoconf_path, encoding=_encodings["fs"], errors="strict"),
-            mode="r",
             encoding=_encodings["content"],
             errors="replace",
         )
@@ -209,7 +205,7 @@ def _env_update(makelinks, target_root, prev_mtimes, contents, env, writemsg_lev
             if x[:1] == "#":
                 continue
             oldld.append(x[:-1])
-    except (IOError, OSError) as e:
+    except OSError as e:
         if e.errno != errno.ENOENT:
             raise
         oldld = None
@@ -248,7 +244,7 @@ def _env_update(makelinks, target_root, prev_mtimes, contents, env, writemsg_lev
         newprelink.write("# contents of /etc/env.d directory\n")
 
         for x in sorted(potential_lib_dirs) + ["bin", "sbin"]:
-            newprelink.write("-l /%s\n" % (x,))
+            newprelink.write("-l /{}\n".format(x))
         prelink_paths = set()
         prelink_paths |= set(specials.get("LDPATH", []))
         prelink_paths |= set(specials.get("PATH", []))
@@ -269,9 +265,9 @@ def _env_update(makelinks, target_root, prev_mtimes, contents, env, writemsg_lev
                     plmasked = 1
                     break
             if not plmasked:
-                newprelink.write("-h %s\n" % (x,))
+                newprelink.write("-h {}\n".format(x))
         for x in prelink_path_mask:
-            newprelink.write("-b %s\n" % (x,))
+            newprelink.write("-b {}\n".format(x))
         newprelink.close()
 
         # Migration code path.  If /etc/prelink.conf was generated by us, then
@@ -291,7 +287,7 @@ def _env_update(makelinks, target_root, prev_mtimes, contents, env, writemsg_lev
                     f = atomic_ofstream(prelink_conf)
                     f.write("-c /etc/prelink.conf.d/*.conf\n")
                     f.close()
-        except IOError as e:
+        except OSError as e:
             if e.errno != errno.ENOENT:
                 raise
 
@@ -367,7 +363,7 @@ def _env_update(makelinks, target_root, prev_mtimes, contents, env, writemsg_lev
             writemsg_level(
                 _(">>> Regenerating %setc/ld.so.cache...\n") % (target_root,)
             )
-            os.system("cd / ; %s -X -r '%s'" % (ldconfig, target_root))
+            os.system("cd / ; {} -X -r '{}'".format(ldconfig, target_root))
         elif ostype in ("FreeBSD", "DragonFly"):
             writemsg_level(
                 _(">>> Regenerating %svar/run/ld-elf.so.hints...\n") % target_root
@@ -399,9 +395,9 @@ def _env_update(makelinks, target_root, prev_mtimes, contents, env, writemsg_lev
         for k in env_keys:
             v = env[k]
             if v.startswith("$") and not v.startswith("${"):
-                outfile.write("export %s=$'%s'\n" % (k, v[1:]))
+                outfile.write("export {}=$'{}'\n".format(k, v[1:]))
             else:
-                outfile.write("export %s='%s'\n" % (k, v))
+                outfile.write("export {}='{}'\n".format(k, v))
 
     # Create the systemd user environment configuration file
     # /etc/environment.d/10-gentoo-env.conf with the
@@ -417,11 +413,6 @@ def _env_update(makelinks, target_root, prev_mtimes, contents, env, writemsg_lev
         systemd_gentoo_env.write(senvnotice)
 
         for env_key in env_keys:
-            # Skip PATH since this makes it impossible to use
-            # "systemctl --user import-environment PATH".
-            if env_key == "PATH":
-                continue
-
             env_key_value = env[env_key]
 
             # Skip variables with the empty string
@@ -442,5 +433,5 @@ def _env_update(makelinks, target_root, prev_mtimes, contents, env, writemsg_lev
     outfile = atomic_ofstream(os.path.join(eroot, "etc", "csh.env"))
     outfile.write(cenvnotice)
     for x in env_keys:
-        outfile.write("setenv %s '%s'\n" % (x, env[x]))
+        outfile.write("setenv {} '{}'\n".format(x, env[x]))
     outfile.close()
